<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>LinetypeSettings</name>
    <message>
        <location filename="../LinetypeSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translation>Standaardinstellingen voor nieuwe tekeningen</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Linetype</source>
        <translation>Lijntype</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Global Linetype Scale:</source>
        <translation>Globale lijntype schaal:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Scale of linetypes matches the scale of each viewport</source>
        <translation>Schaal van linetypes komt overeen met de schaal van elke weergavegebied</translation>
    </message>
</context>
</TS>
